@@ -57,17 +57,12 @@ static void qed_vf_pf_req_end(struct qed_hwfn *p_hwfn, int req_status)
 	mutex_unlock(&(p_hwfn->vf_iov_info->mutex));
 }
 
-#define QED_VF_CHANNEL_USLEEP_ITERATIONS	90
-#define QED_VF_CHANNEL_USLEEP_DELAY		100
-#define QED_VF_CHANNEL_MSLEEP_ITERATIONS	10
-#define QED_VF_CHANNEL_MSLEEP_DELAY		25
-
 static int qed_send_msg2pf(struct qed_hwfn *p_hwfn, u8 *done, u32 resp_size)
 {
 	union vfpf_tlvs *p_req = p_hwfn->vf_iov_info->vf2pf_request;
 	struct ustorm_trigger_vf_zone trigger;
 	struct ustorm_vf_zone *zone_data;
-	int iter, rc = 0;
+	int rc = 0, time = 100;
 
 	zone_data = (struct ustorm_vf_zone *)PXP_VF_BAR0_START_USDM_ZONE_B;
 
@@ -107,19 +102,11 @@ static int qed_send_msg2pf(struct qed_hwfn *p_hwfn, u8 *done, u32 resp_size)
 	REG_WR(p_hwfn, (uintptr_t)&zone_data->trigger, *((u32 *)&trigger));
 
 	/* When PF would be done with the response, it would write back to the
-	 * `done' address from a coherent DMA zone. Poll until then.
+	 * `done' address. Poll until then.
 	 */
-
-	iter = QED_VF_CHANNEL_USLEEP_ITERATIONS;
-	while (!*done && iter--) {
-		udelay(QED_VF_CHANNEL_USLEEP_DELAY);
-		dma_rmb();
-	}
-
-	iter = QED_VF_CHANNEL_MSLEEP_ITERATIONS;
-	while (!*done && iter--) {
-		msleep(QED_VF_CHANNEL_MSLEEP_DELAY);
-		dma_rmb();
+	while ((!*done) && time) {
+		msleep(25);
+		time--;
 	}
 
 	if (!*done) {
@@ -171,7 +158,6 @@ static int qed_vf_pf_acquire(struct qed_hwfn *p_hwfn)
 	struct pfvf_acquire_resp_tlv *resp = &p_iov->pf2vf_reply->acquire_resp;
 	struct pf_vf_pfdev_info *pfdev_info = &resp->pfdev_info;
 	struct vf_pf_resc_request *p_resc;
-	u8 retry_cnt = VF_ACQUIRE_THRESH;
 	bool resources_acquired = false;
 	struct vfpf_acquire_tlv *req;
 	int rc = 0, attempts = 0;
@@ -217,15 +203,6 @@ static int qed_vf_pf_acquire(struct qed_hwfn *p_hwfn)
 
 		/* send acquire request */
 		rc = qed_send_msg2pf(p_hwfn, &resp->hdr.status, sizeof(*resp));
-
-		/* Re-try acquire in case of vf-pf hw channel timeout */
-		if (retry_cnt && rc == -EBUSY) {
-			DP_VERBOSE(p_hwfn, QED_MSG_IOV,
-				   "VF retrying to acquire due to VPC timeout\n");
-			retry_cnt--;
-			continue;
-		}
-
 		if (rc)
 			goto exit;
 
@@ -384,9 +361,6 @@ int qed_vf_hw_prepare(struct qed_hwfn *p_hwfn)
 						    p_iov->bulletin.size,
 						    &p_iov->bulletin.phys,
 						    GFP_KERNEL);
-	if (!p_iov->bulletin.p_virt)
-		goto free_pf2vf_reply;
-
 	DP_VERBOSE(p_hwfn, QED_MSG_IOV,
 		   "VF's bulletin Board [%p virt 0x%llx phys 0x%08x bytes]\n",
 		   p_iov->bulletin.p_virt,
@@ -400,10 +374,6 @@ int qed_vf_hw_prepare(struct qed_hwfn *p_hwfn)
 
 	return qed_vf_pf_acquire(p_hwfn);
 
-free_pf2vf_reply:
-	dma_free_coherent(&p_hwfn->cdev->pdev->dev,
-			  sizeof(union pfvf_tlvs),
-			  p_iov->pf2vf_reply, p_iov->pf2vf_reply_phys);
 free_vf2pf_request:
 	dma_free_coherent(&p_hwfn->cdev->pdev->dev,
 			  sizeof(union vfpf_tlvs),
